
# This file was generated by 'versioneer.py' (0.20) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-03-04T14:38:47-0500",
 "dirty": false,
 "error": null,
 "full-revisionid": "4ff92133a9da6b2fe6cfb0fea7223a339c3cf0f8",
 "version": "2023.3.0"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
